require(raster)
require(rgdal)
require(data.table)
require(reshape2)
library(sp)
library(rworldmap)
library(RColorBrewer)
library( ggplot2 )
theme_set( theme_bw() )
library(dplyr)

yy <- 2050
scen <- 'RCP8.5' #set to RCP8.5 or RCP4.5
setwd('C:/Users/vruijven/Documents/DARE files/')

# Population  data vs latitude

# read the data
spatpop <- fread('Data/spatial_pop_yrs.csv')
spatpop2010 <- fread('Data/spatial_pop_2010.csv')

# Select only 2050 and sum by latitude
spatpop <- subset(spatpop, Year==yy)
spatpop <- as.data.table(spatpop,key="layer")
spatpop <- spatpop[,sum(layer),by=c('y','SCENARIO','Year')]

# sum 2010 data by latitude
spatpop2010 <- as.data.table(spatpop2010,key="layer")
spatpop2010 <- spatpop2010[,sum(layer),by=c('y','SCENARIO','Year')]
spatpop2010$Year <- yy

# merge datasets and prepare for plot
spatpoptemp <- rbind(spatpop,spatpop2010)
spatpoptemp$Year <- as.factor(spatpoptemp$Year)
spatpoptemp$SCENARIO <- 

# Create plot
p <- ggplot( spatpoptemp, aes( y, V1/1e+6, color=SCENARIO,linetype=SCENARIO)) + stat_smooth(method='loess',se=FALSE, na.rm=TRUE, span=0.2) #method="glm", method.args=list(family="quasipoisson"), formula = y ~ ns(x, 3))
p <- p + scale_colour_manual(values = c( "#e41a1c","#377eb8","#4daf4a","#984ea3","#ff7f00","black"),guide = guide_legend(title = NULL)) 
p <- p + scale_linetype_manual(values=c(1,1,1,1,1,2),guide = guide_legend(title = NULL)) + theme_bw(base_size = 25) 
p <- p + xlab("latitude ") + ylab("million people")  + ylim(0,NA)
ggsave( "Figures/Figure1/latitude_vs_population.png",width = 11, height = 7  )


# Energy data vs latitude
# read the data and generate additional variables of interest and select only a single climate model/sector/fuel combination
ClimEnergyTotals <- fread( paste0('Data/',scen,'_ClimEnergyTotals_v2_',yy,"_tot.csv"))
ClimEnergyTotals[,TotEnChg:=TotEn/TotEnHist,]
ClimEnergyTotals[,TotEnClimChg:=EnClim/TotEn,]
ClimEnergyTotals <- subset(ClimEnergyTotals,gcm=='ACCESS1-0' & Fuel=='Total' & Sector=='Total' & HC=='tot')

# Sum by latitude
Totals <- ClimEnergyTotals[,list(sum(histpeople,na.rm=TRUE),
                                 sum(people,na.rm=TRUE),
                                 sum(TotEn,na.rm=TRUE),
                                 sum(TotEnHist,na.rm=TRUE)),by=c("y","SCENARIO")]
setnames(Totals,c("y","SCENARIO",'histpeople','people','TotEn','TotEnHist'))

# Calculate per capita values
Totals[,TotEnPC:=TotEn/people,]
Totals[,TotEnHistPC:=TotEnHist/histpeople,]

# Clean up for plot
TotEnHist <- subset(Totals,SCENARIO=='SSP1',select=c('y','SCENARIO','TotEnHist','TotEnHistPC'))
TotEnHist$SCENARIO <- "2010"
TotEnHist$TotEnHist <- TotEnHist$TotEnHist
TotEnHist$TotEnHistPC <- TotEnHist$TotEnHistPC
setnames(TotEnHist,c("y","SCENARIO",'TotEn','TotEnPC'))

TotEn <- subset(Totals,select=c('y','SCENARIO','TotEn','TotEnPC'))
TotEn <- rbind(TotEn,TotEnHist)
TotEn$SCENARIO <- factor(TotEn$SCENARIO,levels=c("SSP1","SSP2","SSP3","SSP4","SSP5","2010"))

# Create plot
p <- ggplot( TotEn, aes( y, TotEn/1000, color=SCENARIO,linetype=SCENARIO)) + stat_smooth(method='loess',se=FALSE, na.rm=TRUE, span=0.1) #method="glm", method.args=list(family="quasipoisson"), formula = y ~ ns(x, 3))
p <- p + scale_colour_manual(values = c( "#e41a1c","#377eb8","#4daf4a","#984ea3","#ff7f00","black"),guide = guide_legend(title = NULL)) 
p <- p + scale_linetype_manual(values=c(1,1,1,1,1,2),guide = guide_legend(title = NULL)) + theme_bw(base_size = 25) 
p <- p + xlab("latitude ") + ylab("EJ")  + ylim(0,NA)
ggsave( paste0( "Figures/Figure1/latitude_vs_TotEn_",yy,".png"),width = 11, height = 7  )

p <- ggplot( TotEn, aes( y, TotEnPC, color=SCENARIO,linetype=SCENARIO)) + stat_smooth(method='loess',se=FALSE, na.rm=TRUE, span=0.2) #method="glm", method.args=list(family="quasipoisson"), formula = y ~ ns(x, 3))
p <- p + scale_colour_manual(values = c( "#e41a1c","#377eb8","#4daf4a","#984ea3","#ff7f00","black"),guide = guide_legend(title = NULL)) 
p <- p + scale_linetype_manual(values=c(1,1,1,1,1,2),guide = guide_legend(title = NULL)) + theme_bw(base_size = 25) 
p <- p + xlab("latitude ") + ylab("PJ")  + ylim(0,NA)
ggsave( paste0( "Figures/Figure1/latitude_vs_TotEnPC_",yy,".png"),width = 11, height = 7  )


# Temperature data vs latitude

# This code generates a set of climate-only data from the large datafile, by selecting only one fuel/sector combination
# ClimateData <- fread( paste0('Data/',scen,'_EnergyImpacts_HotCold_',yy,".csv"))
# ClimateData <- subset(ClimateData,Fuel=='elc' & Sector=='res')
# write.csv(ClimateData,paste('Data/',scen,'_ClimateData_small_',yy,'.csv',sep=''),row.names=F)

# read data
ClimateData <- fread(paste('Data/',scen,'_ClimateData_small_',yy,'.csv',sep=''))

# Take mean by latitude
ClimateData <- ClimateData[,list(mean(t_g_27p5_fut,na.rm=TRUE),
                                                mean(t_g_27p5_2011,na.rm=TRUE),
                                                mean(t_s_12p5_fut,na.rm=TRUE),
                                                mean(t_s_12p5_2011,na.rm=TRUE)),by=c("y","gcm")]
setnames(ClimateData,c("y","gcm",'t_g_27p5_fut','t_g_27p5_2011','t_s_12p5_fut','t_s_12p5_2011'))

# Create plot
p <- ggplot( ClimateData, aes( y, t_g_27p5_fut, group=gcm,colour="pink"))+ geom_smooth(method='loess',se=FALSE,na.rm=TRUE,alpha=0.2, span=0.1)
p <- p + geom_smooth(data=ClimateData, aes( y, t_g_27p5_2011, group=gcm,colour="light blue"),method='loess',se=FALSE,na.rm=TRUE,alpha=0.2, span=0.1)
p <- p + geom_smooth(data=ClimateData,aes( y, t_g_27p5_fut,group=NULL,colour="red"),method='loess',se=TRUE,na.rm=TRUE,alpha=0.2, span=0.1)
p <- p + geom_smooth(data=ClimateData,aes( y, t_g_27p5_2011,group=NULL,colour="dark blue"),method='loess',se=TRUE,na.rm=TRUE,alpha=0.2, span=0.1)
p <- p + scale_colour_manual(values =c('pink'='pink','light blue'='light blue', 'red'='red', 'dark blue' = 'dark blue'),
                             breaks = c('pink', 'light blue','red','dark blue'),
                             labels = c('gcms 2050','gcms 2010', 'mean 2050', 'mean 2010'),guide = guide_legend(title = NULL))
p <- p + xlab("latitude ") + ylab("days above 27.5C") + ylim(0,NA) + xlim(min(Totals$y),max(Totals$y)) + theme_bw(base_size = 25) + theme(legend.key = element_blank())
ggsave( paste(  "Figures/Figure1/latitude_vs_HotDays_",yy,".png", sep="" ),width = 11, height = 7  )

p <- ggplot( ClimateData, aes( y, t_s_12p5_fut, group=gcm,colour="pink"))+ geom_smooth(method='loess',se=FALSE,na.rm=TRUE,alpha=0.2, span=0.1)
p <- p + geom_smooth(data=ClimateData, aes( y, t_s_12p5_2011, group=gcm,colour="light blue"),method='loess',se=FALSE,na.rm=TRUE,alpha=0.2, span=0.1)
p <- p + geom_smooth(data=ClimateData,aes( y, t_s_12p5_fut,group=NULL,colour="red"),method='loess',se=FALSE,na.rm=TRUE,alpha=0.2, span=0.1)
p <- p + geom_smooth(data=ClimateData,aes( y, t_s_12p5_2011,group=NULL,colour="dark blue"),method='loess',se=FALSE,na.rm=TRUE,alpha=0.2, span=0.1)
p <- p + scale_colour_manual(values =c('pink'='pink','light blue'='light blue', 'red'='red', 'dark blue' = 'dark blue'),
                             breaks = c('pink', 'light blue','red','dark blue'),
                             labels = c('gcms 2050','gcms 2010', 'mean 2050', 'mean 2010'),guide = guide_legend(title = NULL))
p <- p + xlab("latitude ") + ylab("days below 12.5C") + ylim(0,365) + xlim(min(Totals$y),max(Totals$y)) + theme_bw(base_size = 25)  + theme(legend.key = element_blank())
ggsave( paste(  "Figures/Figure1/latitude_vs_ColdDays_",yy,".png", sep="" ),width = 11, height = 7  )


# GDP per capita vs latitude

# Read data
spatpoptot <- fread('Data/spatial_pop_total.csv')
spatpop2010 <- fread('Data/spatial_pop_2010.csv')
SSPData <- fread('Data/SSP_GDP.csv')

# Convert population to numeric values
spatpoptot$histpeople <- as.numeric(spatpoptot$histpeople)
spatpoptot$Year <- as.numeric(spatpoptot$Year)
spatpoptot$people <- as.numeric(spatpoptot$people)
spatpoptot$change <- as.numeric(spatpoptot$change)

# Select only necessary GDP data
GDPpc <- subset(SSPData,select=c("ISO3","Year","SCENARIO",'gdppc'))
GDPpc$Year <- as.numeric(GDPpc$Year)

# Select historic data (2010 is baseyear for all SSPs)
GDPpc2010 <- subset(GDPpc,Year==2010&SCENARIO=='SSP1')
spatpop2010$Year <- as.numeric(spatpop2010$Year)

# Merge population and GDP data
GDPDataMap <- merge(spatpoptot,GDPpc,by=c("SCENARIO","Year","ISO3"),all=FALSE, allow.cartesian = TRUE)
GDPDataMap2010 <- merge(spatpop2010,GDPpc2010,by=c("Year","ISO3"),all=FALSE, allow.cartesian = TRUE)

# Clean up for graph
GDPDataMapHist <- subset(GDPDataMap2010,select=c('x','y','gdppc','layer'))
GDPDataMapHist$SCENARIO <- "2010"
GDPDataMapHist$layer <- as.numeric(GDPDataMapHist$layer)
setnames(GDPDataMapHist,c('x',"y",'gdppc','people',"SCENARIO"))
GDPDataMapHist[,total:=people*gdppc,by=c('x','y')]
GDPDataMapHist2 <- GDPDataMapHist[,sum(total)/sum(people),by='y']
setkey(GDPDataMapHist2,y)
GDPDataMapHist2$SCENARIO <- "2010"
setnames(GDPDataMapHist2,c("y",'gdppc',"SCENARIO"))
GDPDataMap2 <- subset(GDPDataMap,Year=2050,select=c('x','y','SCENARIO','gdppc','people'))
GDPDataMap2[,total:=people*gdppc,by=c('x','y','SCENARIO')]
GDPDataMap3 <- GDPDataMap2[,sum(total)/sum(people),by=c('y','SCENARIO')]
setnames(GDPDataMap3,c("y","SCENARIO",'gdppc'))
GDPDataMap4 <- rbind(GDPDataMap3,GDPDataMapHist2)
GDPDataMap4$SCENARIO <- factor(GDPDataMap4$SCENARIO,levels=c("SSP1","SSP2","SSP3","SSP4","SSP5","2010"))

p <- ggplot( GDPDataMap4, aes( y, gdppc, color=SCENARIO,linetype=SCENARIO)) + stat_smooth(se=FALSE, na.rm=TRUE, span=0.1) #method="glm", method.args=list(family="quasipoisson"), formula = y ~ ns(x, 3))
p <- p + scale_colour_manual(values = c( "#e41a1c","#377eb8","#4daf4a","#984ea3","#ff7f00","black"),guide = guide_legend(title = NULL)) 
p <- p + scale_linetype_manual(values=c(1,1,1,1,1,2),guide = guide_legend(title = NULL)) + theme_bw(base_size = 25) 
p <- p + xlab("latitude ") + ylab("USD per capita")  + ylim(0,NA)
ggsave( paste0( "Figures/Figure1/latitude_vs_gdppc_",yy,".png"),width = 11, height = 7  )


