require(raster)
require(rgdal)
require(data.table)
require(reshape2)
library(sp)
library(rworldmap)
library(RColorBrewer)
library( ggplot2 )
theme_set( theme_bw() )
library(dplyr)

yy <- 2050
scen <- 'RCP8.5' #set to RCP8.5 or RCP4.5
setwd('C:/Users/vruijven/Documents/DARE files/')

#read data
ClimEnergyTotals <- fread( paste0('Data/',scen,'_ClimEnergyTotals_v2_',yy,"_tot.csv"))
ClimEnergyTotals[,TotEnChg:=TotEn/TotEnHist,]
ClimEnergyTotals[,TotEnClimChg:=EnClim/TotEn,]
ClimEnergyTotals <- subset(ClimEnergyTotals,select=c('x','y','SCENARIO','gcm','TotEn','TotEnHist','EnClim'))

ClimateData <- fread( paste0('Data/',scen,'_EnergyImpacts_HotCold_',yy,".csv"))
ClimateData <- subset(ClimateData,Fuel=='elc' & Sector=='res')
ClimateData <- subset(ClimateData,select=c('x','y','gcm','t_g_27p5_chg','t_s_12p5_chg'))
ClimateData <- merge(ClimEnergyTotals,ClimateData,by=c('x','y','gcm'),allow.cartesian=TRUE)

# Bin cells by nr of hot days
TempBins <- seq(0,365,1)
ClimateData$int <- findInterval(ClimateData$t_g_27p5_chg, TempBins)
ClimateDataTest <- ClimateData[,list(sum(TotEn,na.rm=TRUE),
                                                    sum(TotEnHist,na.rm=TRUE),
                                                    sum(EnClim,na.rm=TRUE)),by=c("int","gcm",'SCENARIO')]
setnames(ClimateDataTest,c("t_g_27p5_chg","gcm",'SCENARIO','TotEn','TotEnHist','EnClim'))
setkey(ClimateDataTest,t_g_27p5_chg)

# Make graph only for SSP5 
ClimateDataTemp <- subset(ClimateDataTest,SCENARIO=='SSP5')

p <- ggplot( ClimateDataTemp, aes( t_g_27p5_chg, TotEn/1000, group=gcm,colour="pink"))+ geom_line(stat="smooth",na.rm=TRUE,method='loess',alpha=.7,span=0.2)
p <- p + geom_line(data=ClimateDataTemp, aes( t_g_27p5_chg, TotEnHist/1000, group=gcm,colour="light blue"),stat="smooth",se=FALSE,na.rm=TRUE,method='loess',alpha=.7,span=0.2)
p <- p + geom_line(data=ClimateDataTemp, aes( t_g_27p5_chg, EnClim/1000, group=gcm,colour="tan"),stat="smooth",se=FALSE,na.rm=TRUE,method='loess',alpha=.7,span=0.2)
p <- p + geom_smooth(data=ClimateDataTemp,aes( t_g_27p5_chg, TotEn/1000,group=NULL,colour="red"),se=FALSE,na.rm=FALSE,method='loess',span=0.2)
p <- p + geom_smooth(data=ClimateDataTemp,aes( t_g_27p5_chg, TotEnHist/1000,group=NULL,colour="dark blue"),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + geom_smooth(data=ClimateDataTemp,aes( t_g_27p5_chg, EnClim/1000,group=NULL,colour="darkorange4"),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + scale_colour_manual(values =c('light blue'='light blue','pink'='pink','tan'='tan','dark blue' = 'dark blue', 'red'='red',  'darkorange4'='darkorange4'),
                             breaks = c('light blue','pink', 'tan','dark blue','red','darkorange4'),
                             labels = c('gcms 2010','gcms 2050 SSP5 BaU','gcms with CC' ,'mean 2010','mean 2050 SSP5 BaU',  'mean 2050 with CC'),guide = guide_legend(title = NULL))
p <- p + xlab("2010-2050 change in days above 27.5C") + ylab("Total Energy Use (EJ)") + coord_cartesian(ylim=c(0,45),xlim=c(0,100),expand=FALSE)   + theme_bw(base_size = 25)  #+ theme(legend.position="bottom") #+ xlim(min(Totals$y),max(Totals$y))
ggsave( paste( 'Figures/Figure2/',scen,"_HotDays_vs_Energy_SSP5_",yy,".png", sep="" ),width = 11, height = 7  )

ClimateDataTemp$SCENARIO <- '2010'

p <- ggplot( ClimateDataTest)
p <- p + geom_smooth(data=ClimateDataTest,aes( t_g_27p5_chg, TotEn/1000, group=SCENARIO,linetype="solid",colour=SCENARIO),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + geom_smooth(data=ClimateDataTemp,aes( t_g_27p5_chg, TotEnHist/1000,group=NULL,linetype='dotted',colour=SCENARIO),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + geom_smooth(data=ClimateDataTest,aes( t_g_27p5_chg, EnClim/1000,group=SCENARIO,colour=SCENARIO,linetype='dashed'),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + scale_linetype_manual(values =c('dotted' = 'dotted', 'solid'='solid',  'dashed'='dashed'),
                               breaks = c('dotted','solid','dashed'),
                               labels = c('mean 2010','mean 2050 BaU',  'mean 2050 with CC'),guide = guide_legend(title = NULL))
p <- p + scale_colour_manual(values = c( "black","#e41a1c","#377eb8","#4daf4a","#984ea3","#ff7f00"),
                             #                              breaks = c( "black","#e41a1c","#377eb8","#4daf4a","#984ea3","#ff7f00"),
                             labels = c( "2010", "SSP1", "SSP2", "SSP3", "SSP4", "SSP5"),guide = guide_legend(title = NULL)) 
p <- p + xlab("2010-2050 change in days above 27.5C") + ylab("Total Energy Use (EJ)") + coord_cartesian(ylim=c(0,45),xlim=c(0,100),expand=FALSE)   + theme_bw(base_size = 25)  #+ theme(legend.position="bottom") #+ xlim(min(Totals$y),max(Totals$y))
ggsave( paste( 'Figures/Figure2/',scen,"_HotDays_vs_Energy_SSPs_",yy,".png", sep="" ),width = 11, height = 7  )


# Make same graphs for cold days
TempBins <- seq(0,365,1)
ClimateData$int <- findInterval(-ClimateData$t_s_12p5_chg, TempBins)
ClimateDataTest <- ClimateData[,list(sum(TotEn,na.rm=TRUE),
                                     sum(TotEnHist,na.rm=TRUE),
                                     sum(EnClim,na.rm=TRUE)),by=c("int","gcm",'SCENARIO')]
setnames(ClimateDataTest,c("t_s_12p5_chg","gcm",'SCENARIO','TotEn','TotEnHist','EnClim'))
setkey(ClimateDataTest,t_s_12p5_chg)

ClimateDataTemp <- subset(ClimateDataTest,SCENARIO=='SSP5')

p <- ggplot( ClimateDataTemp, aes( -t_s_12p5_chg, TotEn/1000, group=gcm,colour="pink"))+ geom_line(stat="smooth",na.rm=TRUE,method='loess',alpha=.7,span=0.2)
p <- p + geom_line(data=ClimateDataTemp, aes( -t_s_12p5_chg, TotEnHist/1000, group=gcm,colour="light blue"),stat="smooth",se=FALSE,na.rm=TRUE,method='loess',alpha=.7,span=0.2)
# p <- p + geom_point(data=ClimateDataTemp, aes( -t_s_12p5_chg, EnClim, colour="light blue"))
p <- p + geom_line(data=ClimateDataTemp, aes( -t_s_12p5_chg, EnClim/1000, group=gcm,colour="tan"),stat="smooth",se=FALSE,na.rm=TRUE,method='loess',alpha=.7,span=0.2)
p <- p + geom_smooth(data=ClimateDataTemp,aes( -t_s_12p5_chg, TotEn/1000,group=NULL,colour="red"),se=FALSE,na.rm=FALSE,method='loess',span=0.2)
p <- p + geom_smooth(data=ClimateDataTemp,aes( -t_s_12p5_chg, TotEnHist/1000,group=NULL,colour="dark blue"),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + geom_smooth(data=ClimateDataTemp,aes( -t_s_12p5_chg, EnClim/1000,group=NULL,colour="darkorange4"),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + scale_colour_manual(values =c('light blue'='light blue','pink'='pink','tan'='tan','dark blue' = 'dark blue', 'red'='red',  'darkorange4'='darkorange4'),
                             breaks = c('light blue','pink', 'tan','dark blue','red','darkorange4'),
                             labels = c('gcms 2010','gcms 2050 SSP5 BaU','gcms with CC' ,'mean 2010','mean 2050 SSP5 BaU',  'mean 2050 with CC'),guide = guide_legend(title = NULL))
p <- p + xlab("2010-2050 change in days below 12.5C") + ylab("Total Energy Use (EJ)") + coord_cartesian(ylim=c(0,45),xlim=c(-50,0),expand=FALSE)   + theme_bw(base_size = 25)  #+ theme(legend.position="bottom") #+ xlim(min(Totals$y),max(Totals$y))
ggsave( paste( 'Figures/Figure2/',scen,"_ColdDays_vs_Energy_SSP5_",yy,".png", sep="" ),width = 11, height = 7  )

ClimateDataTemp$SCENARIO <- '2010'

p <- ggplot( ClimateDataTest)
p <- p + geom_smooth(data=ClimateDataTest,aes( -t_s_12p5_chg, TotEn/1000, group=SCENARIO,linetype="solid",colour=SCENARIO),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + geom_smooth(data=ClimateDataTemp,aes( -t_s_12p5_chg, TotEnHist/1000,group=NULL,linetype='dotted',colour=SCENARIO),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + geom_smooth(data=ClimateDataTest,aes( -t_s_12p5_chg, EnClim/1000, group=SCENARIO,colour=SCENARIO,linetype='dashed'),se=FALSE,na.rm=TRUE,method='loess',span=0.2)
p <- p + scale_linetype_manual(values =c('dotted' = 'dotted', 'solid'='solid',  'dashed'='dashed'),
                               breaks = c('dotted','solid','dashed'),
                               labels = c('mean 2010','mean 2050 BaU',  'mean 2050 with CC'),guide = guide_legend(title = NULL))
p <- p + scale_colour_manual(values = c( "black","#e41a1c","#377eb8","#4daf4a","#984ea3","#ff7f00"),
                             #                              breaks = c( "black","#e41a1c","#377eb8","#4daf4a","#984ea3","#ff7f00"),
                             labels = c( "2010", "SSP1", "SSP2", "SSP3", "SSP4", "SSP5"),guide = guide_legend(title = NULL)) 
p <- p + xlab("2010-2050 change in days below 12.5C") + ylab("Total Energy Use (EJ)") + coord_cartesian(ylim=c(0,45), xlim=c(-50,0),expand=FALSE)   + theme_bw(base_size = 25) #+ theme(legend.position="bottom") #+ xlim(min(Totals$y),max(Totals$y)) ,
ggsave( paste( 'Figures/Figure2/',scen,"_ColdDays_vs_Energy_SSPs_",yy,".png", sep="" ),width = 11, height = 7  )

