require(data.table)
library(RColorBrewer)
library( ggplot2 )
theme_set( theme_bw() )

yy <- 2050
setwd('C:/Users/vruijven/Documents/DARE files/')

for(scen in c('RCP4.5','RCP8.5')){  

  # Read data file
  temp_all <- fread(paste0('Data/',scen,'_aggregate_6R_',yy,'.csv'))

  #Calculate absolute and relative changes in energy use
  temp_all[,TotEnAbs:=0.001*(TotEn-(TotEnHist)),]
  temp_all[,TotEnClimAbs:=0.001*(EnClim-TotEn),]
  temp_all[,TotEnPerc:=TotEn/(TotEnHist),]
  temp_all[,TotEnClimPerc:=((EnClim/TotEn)-1)*100,]

#Loop over all regions
for(rr in unique(temp_all$REGION)){

  #Select only region/sectors that are needed for figure
  temp <- subset(temp_all,REGION==rr)
  tmp2 <- subset(temp,HC=='tot' & Fuel=='Total' & Sector=='Total')
  tmp2 <- subset(tmp2, select=c('SCENARIO','REGION','gcm','TotEn'))
  setnames(tmp2,'TotEn','TotalEn')

  #Change naming of Fuels 
  temp$Fuel <- ifelse(temp$Fuel=='elc','Electricity',temp$Fuel)
  temp$Fuel <- ifelse(temp$Fuel=='gaz','Natural Gas',temp$Fuel)
  temp$Fuel <- ifelse(temp$Fuel=='pet','Petroleum',temp$Fuel)

  #Change naming of Sectors 
  temp$Sector <- ifelse(temp$Sector=='agr','Agriculture',temp$Sector)
  temp$Sector <- ifelse(temp$Sector=='ind','Industry',temp$Sector)
  temp$Sector <- ifelse(temp$Sector=='res','Residential',temp$Sector)
  temp$Sector <- ifelse(temp$Sector=='ter','Services',temp$Sector)

  #create dataset of median total energy change and interquartile range
  impacts <- temp[,list(median(TotEnClimAbs),
                        quantile(TotEnClimAbs,0.25,na.rm=TRUE),
                        quantile(TotEnClimAbs,0.75,na.rm=TRUE)),by=c('Fuel',"Sector",'SCENARIO')]
  setnames(impacts,c('Fuel','Sector','SCENARIO','Median','Low','High'))

  #Convert sectors and scenarios to factors
  impacts$Sector <- factor(impacts$Sector,levels=c('Agriculture','Industry', 'Residential','Services','Total'))
  impacts$SCENARIO <- factor(impacts$SCENARIO)

  #Create plot
  p <- ggplot()
  p <- p + geom_bar(data=impacts, aes(x=SCENARIO, y=Median, fill=Fuel), stat='identity', position=position_dodge(0.9))
  p <- p + geom_errorbar(data=impacts, aes(x=SCENARIO, ymin=Low, ymax=High, group=Fuel), position=position_dodge(0.9), width=0.25)
  p <- p + theme_bw(base_size = 25)
  p <- p + theme(axis.title.x=element_blank()) + ylab('EJ')
  p <- p + facet_wrap(~Sector,scales='free_y') + theme(strip.background = element_blank())
  ggsave( paste0("Figures/Figure3/",scen,"_Decomposition_",rr,".png"),width = 18, height = 7  )
  ggsave( paste0("Figures/Figure3/",scen,"_Decomposition_",rr,".pdf"),width = 18, height = 7  )
  
  #Save data file for Global Figure in paper
  if(rr=='World'){
    write.csv(impacts, file = paste0('Figures/Figure3/',scen,'_Figure3.csv'),row.names = FALSE)
  }
  
  #create dataset of median percentage energy change and interquartile range
  impacts <- temp[,list(median(TotEnClimPerc),
                        quantile(TotEnClimPerc,0.25,na.rm=TRUE),
                        quantile(TotEnClimPerc,0.75,na.rm=TRUE)),by=c('Fuel',"Sector",'SCENARIO')]
  setnames(impacts,c('Fuel','Sector','SCENARIO','Median','Low','High'))

  #Convert sectors and scenarios to factors
  impacts$Sector <- factor(impacts$Sector,levels=c('Agriculture','Industry', 'Residential','Services','Total'))
  impacts$SCENARIO <- factor(impacts$SCENARIO)

  #Create plot
  p <- ggplot()
  p <- p + geom_bar(data=impacts, aes(x=SCENARIO, y=Median, fill=Fuel), stat='identity', position=position_dodge(0.9))
  p <- p + geom_errorbar(data=impacts, aes(x=SCENARIO, ymin=Low, ymax=High, group=Fuel), position=position_dodge(0.9), width=0.25)
  p <- p + theme_bw(base_size = 25)
  p <- p + theme(axis.title.x=element_blank()) + ylab('Percent')
  p <- p + facet_wrap(~Sector,scales='free_y') + theme(strip.background = element_blank())
  ggsave( paste0("Figures/Figure3/",scen,"_Decomposition_",rr,"_perc.png"),width = 18, height = 7  )
  ggsave( paste0("Figures/Figure3/",scen,"_Decomposition_",rr,"_perc.pdf"),width = 18, height = 7  )

}}