require(raster)
require(rgdal)
require(data.table)
require(reshape2)
library(sp)
library(rworldmap)
library(RColorBrewer)
library( ggplot2 )
theme_set( theme_bw() )
library(dplyr)

yy <- 2050
scen <- 'RCP8.5' #set to RCP8.5 or RCP4.5
setwd('C:/Users/vruijven/Documents/DARE files/')

#read data
ClimEnergyTotals <- fread( paste0('Data/',scen,'_ClimEnergyTotals_v2_',yy,"_tot.csv"))
ClimEnergyTotals[,TotEnChg:=TotEn/TotEnHist,]
ClimEnergyTotals[,TotEnClimChg:=EnClim/TotEn,]

# Create vector for binning
EnBins <- seq(0,3,0.05)

for(ss in unique(ClimEnergyTotals$SCENARIO)){

  ss <- 'SSP1'
  
ClimEnergyTotalSSP <- subset(ClimEnergyTotals,SCENARIO==ss & TotEn>0)
ClimEnergyTotalSSP_map0 <- subset(ClimEnergyTotalSSP,select=c('x','y','TotEnClimChg'))

mapDevice(device="png",rows=4,columns=1,file=paste('Figures/Figure4/',scen,"_ExceedanceMap_",ss,"_",yy,".png",sep=''))

for(ee in c(1,1.1,1.25,1.5)){
  ClimEnergyTotalSSP_map <- ClimEnergyTotalSSP_map0[,v:=sum(TotEnClimChg>ee),by=c("x","y")]
  coordinates(ClimEnergyTotalSSP_map) = c("x", "y")
  # promote to SpatialPixelsDataFrame
  gridded(ClimEnergyTotalSSP_map) <- TRUE
  gridded(ClimEnergyTotalSSP_map) <- TRUE
  numCats <- 7 #set number of categories to use
  palette = colorRampPalette((brewer.pal(n=11, name='Reds')))(numCats)
    sTMP = as(ClimEnergyTotalSSP_map, "SpatialGridDataFrame")
  mapParams <- mapGriddedData(sTMP,nameColumnToPlot="v",
                            catMethod=seq(0,21,length.out = numCats+1),
                            numCats=numCats, 
                            colourPalette=palette,
                            addLegend=FALSE,
                            borderCol='black')
  }
  do.call( addMapLegend, c( mapParams, legendLabels="none", legendWidth=4.0,labelFontSize=4))
  dev.off()
}


# AND FOR REDUCTION IN ENERGY USE

for(ss in unique(ClimEnergyTotals$SCENARIO)){

  ClimEnergyTotalSSP <- subset(ClimEnergyTotals,SCENARIO==ss & TotEn>0)
  ClimEnergyTotalSSP_map0 <- subset(ClimEnergyTotalSSP,select=c('x','y','TotEnClimChg'))
  
  mapDevice(device="png",rows=4,columns=1,file=paste('Figures/Figure4/',scen,"_ExceedanceMap_reduction_",ss,"_",yy,".png",sep=''))
  
  for(ee in c(1,0.9,0.75,0.5)){
    ClimEnergyTotalSSP_map <- ClimEnergyTotalSSP_map0[,v:=sum(TotEnClimChg<ee),by=c("x","y")]
    
    coordinates(ClimEnergyTotalSSP_map) = c("x", "y")
    # promote to SpatialPixelsDataFrame
    gridded(ClimEnergyTotalSSP_map) <- TRUE
    gridded(ClimEnergyTotalSSP_map) <- TRUE
    numCats <- 7 #set number of categories to use
    palette = colorRampPalette((brewer.pal(n=11, name='Blues')))(numCats)
    sTMP = as(ClimEnergyTotalSSP_map, "SpatialGridDataFrame")
    mapParams <- mapGriddedData(sTMP,nameColumnToPlot="v",
                                catMethod=seq(0,21,length.out = numCats+1),
                                numCats=numCats, 
                                colourPalette=palette,
                                addLegend=FALSE,
                                borderCol='black')
    
  }
  do.call( addMapLegend, c( mapParams, legendLabels="none", legendWidth=4.0,labelFontSize=4))
  dev.off()
}

